@@ -28,7 +28,7 @@
 #include "gnome-bindings-prop.h"
 #include "../src/gtkhtml.h"
 
-#define CUSTOM_KEYMAP_NAME "Custom"
+/* #define CUSTOM_KEYMAP_NAME "Custom" */
 #define EMACS_KEYMAP_NAME "Emacs like"
 #define XEMACS_KEYMAP_NAME "XEmacs like"
 #define MS_KEYMAP_NAME "MS like"
@@ -45,8 +45,8 @@ static GtkHTMLClassProperties *saved_prop;
 static GtkHTMLClassProperties *orig_prop;
 static GtkHTMLClassProperties *actual_prop;
 
-static GList *saved_bindings;
-static GList *orig_bindings;
+/* static GList *saved_bindings;
+   static GList *orig_bindings; */
 
 static gchar *home_rcfile;
 
@@ -60,7 +60,6 @@ set_ui ()
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (anim_check), actual_prop->animations);
 
 #define SET_FONT(f,w) \
-        printf ("%s\n", actual_prop-> ## f); \
 	gnome_font_picker_set_font_name (GNOME_FONT_PICKER (w), actual_prop-> ## f);
 
 	SET_FONT (font_var,       variable);
@@ -78,7 +77,8 @@ set_ui ()
 	} else if (!strcmp (actual_prop->keybindings_theme, "ms")) {
 		keymap_name = MS_KEYMAP_NAME;
 	} else
-		keymap_name = CUSTOM_KEYMAP_NAME;
+		keymap_name = MS_KEYMAP_NAME;
+		/* keymap_name = CUSTOM_KEYMAP_NAME; */
 	gnome_bindings_properties_select_keymap (GNOME_BINDINGS_PROPERTIES (bi), keymap_name);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (live_spell_check), actual_prop->live_spell_check);
 	gtk_widget_set_sensitive (live_spell_color, actual_prop->live_spell_check);
@@ -136,11 +136,11 @@ apply_editable (void)
 	gchar *keymap_id, *keymap_name;
 
 	/* bindings */
-	gnome_bindings_properties_save_keymap (GNOME_BINDINGS_PROPERTIES (bi), CUSTOM_KEYMAP_NAME, home_rcfile);
+	/* gnome_bindings_properties_save_keymap (GNOME_BINDINGS_PROPERTIES (bi), CUSTOM_KEYMAP_NAME, home_rcfile);
 	gnome_binding_entry_list_destroy (saved_bindings);
 	saved_bindings = gnome_binding_entry_list_copy (gnome_bindings_properties_get_keymap (GNOME_BINDINGS_PROPERTIES (bi),
 											      CUSTOM_KEYMAP_NAME));
-
+	*/
 	/* properties */
 	actual_prop->magic_links = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (magic_check));
 	keymap_name = gnome_bindings_properties_get_keymap_name (GNOME_BINDINGS_PROPERTIES (bi));
@@ -151,7 +151,8 @@ apply_editable (void)
 	} else if (!strcmp (keymap_name, MS_KEYMAP_NAME)) {
 		keymap_id = "ms";
 	} else
-		keymap_id = "custom";
+		keymap_id = "ms";
+	        /* keymap_id = "custom"; */
 
 	g_free (actual_prop->keybindings_theme);
 	actual_prop->keybindings_theme = g_strdup (keymap_id);
@@ -182,11 +183,11 @@ apply (void)
 static void
 revert (void)
 {
-	gnome_bindings_properties_set_keymap (GNOME_BINDINGS_PROPERTIES (bi), CUSTOM_KEYMAP_NAME, orig_bindings);
+	/* gnome_bindings_properties_set_keymap (GNOME_BINDINGS_PROPERTIES (bi), CUSTOM_KEYMAP_NAME, orig_bindings);
 	gnome_binding_entry_list_destroy (saved_bindings);
 	saved_bindings = gnome_binding_entry_list_copy (orig_bindings);
 	gnome_bindings_properties_save_keymap (GNOME_BINDINGS_PROPERTIES (bi), CUSTOM_KEYMAP_NAME, home_rcfile);
-
+	*/
 #ifdef GTKHTML_HAVE_GCONF
 	gtk_html_class_properties_update (orig_prop, client, saved_prop);
 #else
@@ -213,12 +214,27 @@ live_changed (GtkWidget *widget, gpointer null)
 
 	changed (widget, null);
 }
+
+#define SELECTOR(x) GTK_FONT_SELECTION_DIALOG (GNOME_FONT_PICKER (x)->font_dialog)
+
+static void
+picker_clicked (GtkWidget *w, gpointer data)
+{
+	gchar *mono_spaced [] = { "c", "m", NULL };
+	gchar *proportional [] = { "p", NULL };
+	
+	gtk_font_selection_dialog_set_filter (SELECTOR (w),
+					      GTK_FONT_FILTER_BASE, GTK_FONT_ALL,
+					      NULL, NULL, NULL, NULL,
+					      GPOINTER_TO_INT (data) ? proportional : mono_spaced, NULL);
+}
+
 static void
 setup (void)
 {
 	GtkWidget *vbox, *ebox;
 	GladeXML *xml;
-	char *base, *rcfile;
+	gchar *base, *rcfile;
 
 	glade_gnome_init ();
 	xml = glade_xml_new (GLADE_DATADIR "/gtkhtml-capplet.glade", "prefs_widget");
@@ -237,6 +253,11 @@ setup (void)
 	fixed            = glade_xml_get_widget (xml, "screen_fixed");
 	fixed_print      = glade_xml_get_widget (xml, "print_fixed");
 
+	gtk_signal_connect (GTK_OBJECT (variable),        "clicked", picker_clicked, GINT_TO_POINTER (TRUE));
+	gtk_signal_connect (GTK_OBJECT (variable_print),  "clicked", picker_clicked, GINT_TO_POINTER (TRUE));
+	gtk_signal_connect (GTK_OBJECT (fixed),           "clicked", picker_clicked, GINT_TO_POINTER (FALSE));
+	gtk_signal_connect (GTK_OBJECT (fixed_print),     "clicked", picker_clicked, GINT_TO_POINTER (FALSE));
+
 	anim_check       = glade_xml_get_widget (xml, "anim_check");
 	magic_check      = glade_xml_get_widget (xml, "magic_check");
 	live_spell_check = glade_xml_get_widget (xml, "live_spell_check");
@@ -253,6 +274,7 @@ setup (void)
 	
 	home_rcfile = g_strconcat (gnome_util_user_home (), "/.gnome/gtkhtml-bindings-custom", NULL);
 	gtk_rc_parse (home_rcfile);
+	g_free (home_rcfile);
 	LOAD ("emacs");
 	LOAD ("xemacs");
 	LOAD ("ms");
@@ -267,7 +289,7 @@ setup (void)
 	gnome_bindings_properties_add_keymap (GNOME_BINDINGS_PROPERTIES (bi),
 					      MS_KEYMAP_NAME, "gtkhtml-bindings-ms", "command",
 					      GTK_TYPE_HTML_COMMAND, FALSE);
-	gnome_bindings_properties_add_keymap (GNOME_BINDINGS_PROPERTIES (bi),
+	/* gnome_bindings_properties_add_keymap (GNOME_BINDINGS_PROPERTIES (bi),
 					      CUSTOM_KEYMAP_NAME, "gtkhtml-bindings-custom", "command",
 					      GTK_TYPE_HTML_COMMAND, TRUE);
 	gnome_bindings_properties_select_keymap (GNOME_BINDINGS_PROPERTIES (bi), CUSTOM_KEYMAP_NAME);
@@ -275,6 +297,7 @@ setup (void)
 						       (GNOME_BINDINGS_PROPERTIES (bi), CUSTOM_KEYMAP_NAME));
 	saved_bindings = gnome_binding_entry_list_copy (gnome_bindings_properties_get_keymap
 							(GNOME_BINDINGS_PROPERTIES (bi), CUSTOM_KEYMAP_NAME));
+							gtk_signal_connect (GTK_OBJECT (bi), "changed", changed, NULL); */
 	gtk_signal_connect (GTK_OBJECT (bi), "changed", changed, NULL);
 
 	ebox = glade_xml_get_widget (xml, "bindings_ebox");
