@@ -28,6 +28,7 @@ typedef enum {
 	GTK_HTML_COMMAND_UNDO,
 	GTK_HTML_COMMAND_REDO,
 	GTK_HTML_COMMAND_COPY,
+	GTK_HTML_COMMAND_COPY_AND_DISABLE_SELECTION,
 	GTK_HTML_COMMAND_CUT,
 	GTK_HTML_COMMAND_PASTE,
 
@@ -84,6 +85,7 @@ typedef enum {
 
 	GTK_HTML_COMMAND_INDENT_ZERO,
 	GTK_HTML_COMMAND_INDENT_INC,
+	GTK_HTML_COMMAND_INDENT_INC_OR_NEXT_CELL,
 	GTK_HTML_COMMAND_INDENT_DEC,
 	GTK_HTML_COMMAND_INDENT_DEC_OR_PREV_CELL,
 	GTK_HTML_COMMAND_INDENT_PARAGRAPH,
@@ -103,6 +105,7 @@ typedef enum {
 	GTK_HTML_COMMAND_PARAGRAPH_STYLE_ITEMDOTTED,
 	GTK_HTML_COMMAND_PARAGRAPH_STYLE_ITEMROMAN,
 	GTK_HTML_COMMAND_PARAGRAPH_STYLE_ITEMDIGIT,
+	GTK_HTML_COMMAND_PARAGRAPH_STYLE_ITEMALPHA,
 
 	GTK_HTML_COMMAND_MODIFY_SELECTION_UP,
 	GTK_HTML_COMMAND_MODIFY_SELECTION_DOWN,
@@ -182,6 +185,21 @@ typedef enum {
 	GTK_HTML_COMMAND_ZOOM_IN,
 	GTK_HTML_COMMAND_ZOOM_OUT,
 	GTK_HTML_COMMAND_ZOOM_RESET,
+
+	GTK_HTML_COMMAND_TABLE_SPACING_INC,
+	GTK_HTML_COMMAND_TABLE_SPACING_DEC,
+	GTK_HTML_COMMAND_TABLE_SPACING_ZERO,
+
+	GTK_HTML_COMMAND_TABLE_PADDING_INC,
+	GTK_HTML_COMMAND_TABLE_PADDING_DEC,
+	GTK_HTML_COMMAND_TABLE_PADDING_ZERO,
+
+	GTK_HTML_COMMAND_DELETE_TABLE,
+	GTK_HTML_COMMAND_DELETE_TABLE_ROW,
+	GTK_HTML_COMMAND_DELETE_TABLE_COLUMN,
+	GTK_HTML_COMMAND_DELETE_TABLE_CELL_CONTENTS,
+
+	GTK_HTML_COMMAND_GRAB_FOCUS,
 } GtkHTMLCommandType;
 
 typedef enum {
@@ -193,7 +211,8 @@ typedef enum {
 
 typedef enum {
 	GTK_HTML_EDITOR_EVENT_COMMAND,
-	GTK_HTML_EDITOR_EVENT_IMAGE_URL
+	GTK_HTML_EDITOR_EVENT_IMAGE_URL,
+	GTK_HTML_EDITOR_EVENT_DELETE
 } GtkHTMLEditorEventType;
 
 typedef enum {
@@ -239,7 +258,8 @@ typedef enum {
 	GTK_HTML_PARAGRAPH_STYLE_PRE,
 	GTK_HTML_PARAGRAPH_STYLE_ITEMDOTTED,
 	GTK_HTML_PARAGRAPH_STYLE_ITEMROMAN,
-	GTK_HTML_PARAGRAPH_STYLE_ITEMDIGIT
+	GTK_HTML_PARAGRAPH_STYLE_ITEMDIGIT,
+	GTK_HTML_PARAGRAPH_STYLE_ITEMALPHA
 } GtkHTMLParagraphStyle;
 
 typedef enum {
