@@ -39,6 +39,12 @@ struct _GtkHTMLPrivate {
 	gboolean update_styles;
 
 	gint last_selection_type;
+	/* Used to hold the primary selection when
+	** pasting within ourselves
+	*/
+	HTMLObject *primary;
+	guint       primary_len;
+
 	gchar *content_type;
 
 	GtkWidget *search_input_line;
@@ -52,8 +58,13 @@ struct _GtkHTMLPrivate {
 #endif
 };
 
-void  gtk_html_private_calc_scrollbars  (GtkHTML            *html);
-void  gtk_html_editor_event_command     (GtkHTML            *html,
-					 GtkHTMLCommandType  com_type);
+void  gtk_html_private_calc_scrollbars  (GtkHTML                 *html);
+void  gtk_html_editor_event_command     (GtkHTML                 *html,
+					 GtkHTMLCommandType       com_type);
+void  gtk_html_editor_event             (GtkHTML                 *html,
+					 GtkHTMLEditorEventType   event,
+					 GtkArg                 **args);
 
 #endif /* _GTKHTML_PRIVATE_H */
+
+
