@@ -24,7 +24,7 @@
 #ifndef HTMLCURSOR_H
 #define HTMLCURSOR_H
 
-#include <unicode.h>
+#include <gal/unicode/gunicode.h>
 #include "htmltypes.h"
 
 struct _HTMLCursor {
@@ -37,6 +37,14 @@ struct _HTMLCursor {
 	gint position;
 };
 
+struct _HTMLCursorRectagle {
+	HTMLObject *object;
+	gint x1;
+	gint y1;
+	gint x2;
+	gint y2;
+};
+
 /* Lifecycle.  */
 HTMLCursor *html_cursor_new      (void);
 void        html_cursor_destroy  (HTMLCursor       *cursor);
@@ -50,6 +58,12 @@ gboolean  html_cursor_forward                (HTMLCursor *cursor,
 					      HTMLEngine *engine);
 gboolean  html_cursor_backward               (HTMLCursor *cursor,
 					      HTMLEngine *engine);
+gboolean  html_cursor_forward_n              (HTMLCursor *cursor,
+					      HTMLEngine *e,
+					      guint      n);
+gboolean  html_cursor_backward_n             (HTMLCursor *cursor,
+					      HTMLEngine *e,
+					      guint      n);
 gboolean  html_cursor_up                     (HTMLCursor *cursor,
 					      HTMLEngine *engine);
 gboolean  html_cursor_down                   (HTMLCursor *cursor,
@@ -62,6 +76,10 @@ gboolean  html_cursor_beginning_of_line      (HTMLCursor *cursor,
 					      HTMLEngine *engine);
 gboolean  html_cursor_end_of_line            (HTMLCursor *cursor,
 					      HTMLEngine *engine);
+gboolean  html_cursor_beginning_of_paragraph (HTMLCursor *cursor,
+					      HTMLEngine *engine);
+gboolean  html_cursor_end_of_paragraph       (HTMLCursor *cursor,
+					      HTMLEngine *engine);
 gboolean  html_cursor_jump_to                (HTMLCursor *cursor,
 					      HTMLEngine *engine,
 					      HTMLObject *obj,
@@ -77,8 +95,8 @@ void  html_cursor_jump_to_position  (HTMLCursor *cursor,
 				     gint        position);
 
 /* Retrieving the character under/before the cursor.  */
-unicode_char_t  html_cursor_get_current_char  (const HTMLCursor *cursor);
-unicode_char_t  html_cursor_get_prev_char     (const HTMLCursor *cursor);
+gunichar  html_cursor_get_current_char  (const HTMLCursor *cursor);
+gunichar  html_cursor_get_prev_char     (const HTMLCursor *cursor);
 
 /* Comparison.  */
 gboolean  html_cursor_equal     (const HTMLCursor *a,
