@@ -30,6 +30,7 @@
 /* Properties of a paragraph.  */
 struct _ClueFlowProps {
 	HTMLClueFlowStyle style;
+	HTMLListType item_type;
 	HTMLHAlignType alignment;
 	guint8 indentation;
 };
@@ -39,9 +40,6 @@ typedef struct _ClueFlowProps ClueFlowProps;
 struct _ClueFlowStyleOperation {
 	HTMLUndoData data;
 	
-	/* Whether this is an undo or a redo operation.  */
-	gboolean undo;
-
 	/* Whether we should go backward or forward when re-setting
            the style.  */
 	gboolean forward;
@@ -73,7 +71,7 @@ style_operation_destroy (HTMLUndoData *data)
 }
 
 static ClueFlowStyleOperation *
-style_operation_new (GList *prop_list, gboolean undo, gboolean forward)
+style_operation_new (GList *prop_list, gboolean forward)
 {
 	ClueFlowStyleOperation *op;
 
@@ -83,7 +81,6 @@ style_operation_new (GList *prop_list, gboolean undo, gboolean forward)
 
 	op->data.destroy = style_operation_destroy;
 	op->prop_list    = prop_list;
-	op->undo         = undo;
 	op->forward      = forward;
 
 	return op;
@@ -99,6 +96,7 @@ get_props (HTMLClueFlow *clueflow)
 	props->indentation = html_clueflow_get_indentation (clueflow);
 	props->alignment   = html_clueflow_get_halignment (clueflow);
 	props->style       = html_clueflow_get_style (clueflow);
+	props->item_type   = html_clueflow_get_item_type (clueflow);
 
 	return props;
 }
@@ -107,6 +105,7 @@ static ClueFlowProps *
 get_props_and_set (HTMLEngine *engine,
 		   HTMLClueFlow *clueflow,
 		   HTMLClueFlowStyle style,
+		   HTMLListType item_type,
 		   HTMLHAlignType alignment,
 		   gint indentation,
 		   HTMLEngineSetClueFlowStyleMask mask)
@@ -115,8 +114,10 @@ get_props_and_set (HTMLEngine *engine,
 
 	props = get_props (clueflow);
 
-	if (mask & HTML_ENGINE_SET_CLUEFLOW_STYLE)
+	if (mask & HTML_ENGINE_SET_CLUEFLOW_STYLE) {
 		html_clueflow_set_style (clueflow, engine, style);
+		html_clueflow_set_item_type (clueflow, engine, item_type);
+	}
 	if (mask & HTML_ENGINE_SET_CLUEFLOW_ALIGNMENT)
 		html_clueflow_set_halignment (clueflow, engine, alignment);
 
@@ -205,9 +206,9 @@ undo_or_redo (HTMLEngine *engine, HTMLUndoData *data, HTMLUndoDirection dir)
 
 	prop_list = g_list_reverse (prop_list);
 
-	new_op = style_operation_new (prop_list, ! op->undo, op->forward);
+	new_op = style_operation_new (prop_list, op->forward);
 
-	if (new_op->undo)
+	if (dir == HTML_UNDO_REDO)
 		add_undo (engine, new_op);
 	else
 		add_redo (engine, new_op);
@@ -242,6 +243,7 @@ add_redo (HTMLEngine *engine,
 static void
 set_clueflow_style_in_region (HTMLEngine *engine,
 			      HTMLClueFlowStyle style,
+			      HTMLListType item_type,
 			      HTMLHAlignType alignment,
 			      gint indentation_delta,
 			      HTMLEngineSetClueFlowStyleMask mask,
@@ -276,7 +278,7 @@ set_clueflow_style_in_region (HTMLEngine *engine,
 
 		clueflow = HTML_CLUEFLOW (p->parent);
 		orig_props = get_props_and_set (engine, clueflow,
-						style, alignment, indentation_delta,
+						style, item_type, alignment, indentation_delta,
 						mask);
 
 		if (do_undo) {
@@ -297,12 +299,13 @@ set_clueflow_style_in_region (HTMLEngine *engine,
 	if (! do_undo)
 		return;
 
-	add_undo (engine, style_operation_new (undo_forward ? g_list_reverse (prop_list) : prop_list, TRUE, undo_forward));
+	add_undo (engine, style_operation_new (undo_forward ? g_list_reverse (prop_list) : prop_list, undo_forward));
 }
 
 static void
 set_clueflow_style_at_cursor (HTMLEngine *engine,
 			      HTMLClueFlowStyle style,
+			      HTMLListType item_type,
 			      HTMLHAlignType alignment,
 			      gint indentation_delta,
 			      HTMLEngineSetClueFlowStyleMask mask,
@@ -320,7 +323,7 @@ set_clueflow_style_at_cursor (HTMLEngine *engine,
 
 	clueflow = HTML_CLUEFLOW (curr->parent);
 	props = get_props_and_set (engine, clueflow,
-				   style, alignment, indentation_delta,
+				   style, item_type, alignment, indentation_delta,
 				   mask);
 
 	if (! do_undo) {
@@ -328,13 +331,14 @@ set_clueflow_style_at_cursor (HTMLEngine *engine,
 		return;
 	}
 
-	add_undo (engine, style_operation_new (g_list_append (NULL, props), TRUE, TRUE));
+	add_undo (engine, style_operation_new (g_list_append (NULL, props), TRUE));
 }
 
 
 gboolean
 html_engine_set_clueflow_style (HTMLEngine *engine,
 				HTMLClueFlowStyle style,
+				HTMLListType item_type,
 				HTMLHAlignType alignment,
 				gint indentation_delta,
 				HTMLEngineSetClueFlowStyleMask mask,
@@ -348,12 +352,12 @@ html_engine_set_clueflow_style (HTMLEngine *engine,
 	html_engine_freeze (engine);
 	if (html_engine_is_selection_active (engine))
 		set_clueflow_style_in_region (engine,
-					      style, alignment, indentation_delta,
+					      style, item_type, alignment, indentation_delta,
 					      mask,
 					      do_undo);
 	else
 		set_clueflow_style_at_cursor (engine,
-					      style, alignment, indentation_delta,
+					      style, item_type, alignment, indentation_delta,
 					      mask,
 					      do_undo);
 	html_engine_thaw (engine);
@@ -386,21 +390,24 @@ get_current_para (HTMLEngine *engine)
 	return HTML_CLUEFLOW (parent);
 }
 
-HTMLClueFlowStyle
-html_engine_get_current_clueflow_style (HTMLEngine *engine)
+void
+html_engine_get_current_clueflow_style (HTMLEngine *engine, HTMLClueFlowStyle *style, HTMLListType *item_type)
 {
 	HTMLClueFlow *para;
 
 	/* FIXME TODO region */
 
-	g_return_val_if_fail (engine != NULL, HTML_CLUEFLOW_STYLE_NORMAL);
-	g_return_val_if_fail (HTML_IS_ENGINE (engine), HTML_CLUEFLOW_STYLE_NORMAL);
+	*style = HTML_CLUEFLOW_STYLE_NORMAL;
+	*item_type = HTML_LIST_TYPE_UNORDERED;
+
+	g_return_if_fail (engine != NULL);
+	g_return_if_fail (HTML_IS_ENGINE (engine));
 
 	para = get_current_para (engine);
-	if (para == NULL)
-		return HTML_CLUEFLOW_STYLE_NORMAL;
-
-	return para->style;
+	if (para) {
+		*style = para->style;
+		*item_type = para->item_type;
+	}
 }
  
 guint
@@ -434,5 +441,5 @@ html_engine_get_current_clueflow_alignment (HTMLEngine *engine)
 	if (para == NULL)
 		return 0;
 
-	return HTML_CLUE (para)->halign;
+	return html_clueflow_get_halignment (para);
 }
