@@ -30,6 +30,7 @@
 #include "htmlengine-edit.h"
 #include "htmlengine-edit-cut-and-paste.h"
 #include "htmlengine-edit-table.h"
+#include "htmlengine-edit-tablecell.h"
 #include "htmltable.h"
 #include "htmltablecell.h"
 #include "htmltablepriv.h"
@@ -45,14 +46,14 @@ html_engine_get_table (HTMLEngine *e)
 {
 	if (HTML_IS_TABLE (e->cursor->object))
 		return HTML_TABLE (e->cursor->object);
-	else {
-		g_return_val_if_fail (e->cursor->object->parent
-				  && e->cursor->object->parent->parent
-				  && e->cursor->object->parent->parent->parent, NULL);
-		g_return_val_if_fail (HTML_IS_TABLE (e->cursor->object->parent->parent->parent), NULL);
-
+	else if (!e->cursor->object->parent
+		 || !e->cursor->object->parent->parent
+		 || !e->cursor->object->parent->parent->parent)
+		return NULL;
+	else if (!HTML_IS_TABLE (e->cursor->object->parent->parent->parent))
+		return NULL;
+	else
 		return HTML_TABLE (e->cursor->object->parent->parent->parent);
-	}
 }
 
 static HTMLTableCell *
@@ -63,7 +64,7 @@ new_cell (HTMLEngine *e, HTMLTable *table)
 	HTMLObject    *flow;
 	
 	cell  = html_table_cell_new (1, 1, table->padding);
-	flow  = html_clueflow_new (HTML_CLUEFLOW_STYLE_NORMAL, 0);
+	flow  = html_clueflow_new (HTML_CLUEFLOW_STYLE_NORMAL, 0, HTML_LIST_TYPE_UNORDERED, 0);
 	text  = html_engine_new_text_empty (e);
 
 	html_clue_append (HTML_CLUE (flow), text);
@@ -652,10 +653,9 @@ table_set_border_width (HTMLEngine *e, HTMLTable *t, gint border_width, gboolean
 	HTMLTableSetAttrUndo *undo;
 	gint new_border;
 
-	if (!t || !HTML_IS_TABLE (HTML_OBJECT (t)))
+	if (!t || !HTML_IS_TABLE (t))
 		return;
 
-	html_engine_freeze (e);
 	if (relative)
 		new_border = t->border + border_width;
 	else
@@ -668,6 +668,7 @@ table_set_border_width (HTMLEngine *e, HTMLTable *t, gint border_width, gboolean
 	undo = attr_undo_new (HTML_TABLE_BORDER);
 	undo->attr.border = t->border;
 
+	html_engine_freeze (e);
 	t->border = new_border;
 
 	html_object_change_set (HTML_OBJECT (t), HTML_CHANGE_ALL_CALC);
@@ -716,11 +717,11 @@ table_set_bg_color (HTMLEngine *e, HTMLTable *t, GdkColor *c, HTMLUndoDirection
 						    HTML_UNDO_DATA (undo), html_cursor_get_position (e->cursor)), dir);
 	if (c) {
 		if (!t->bgColor)
-			t->bgColor = g_new (GdkColor, 1);
+			t->bgColor = gdk_color_copy (c);
 		*t->bgColor = *c;
 	} else {
 		if (t->bgColor)
-			g_free (t->bgColor);
+			gdk_color_free (t->bgColor);
 		t->bgColor = NULL;
 	}
 	html_engine_queue_draw (e, HTML_OBJECT (t));
@@ -777,35 +778,48 @@ html_engine_table_set_bg_pixmap (HTMLEngine *e, HTMLTable *t, gchar *url)
  *
  */
 
-static void table_set_spacing (HTMLEngine *e, HTMLTable *t, gint spacing, HTMLUndoDirection dir);
+static void table_set_spacing (HTMLEngine *e, HTMLTable *t, gint spacing, gboolean relative, HTMLUndoDirection dir);
 
 static void
 table_set_spacing_undo_action (HTMLEngine *e, HTMLUndoData *undo_data, HTMLUndoDirection dir)
 {
 	HTMLTableSetAttrUndo *data = (HTMLTableSetAttrUndo *) undo_data;
 
-	table_set_spacing (e, html_engine_get_table (e), data->attr.spacing, html_undo_direction_reverse (dir));
+	table_set_spacing (e, html_engine_get_table (e), data->attr.spacing, FALSE, html_undo_direction_reverse (dir));
 }
 
 static void
-table_set_spacing (HTMLEngine *e, HTMLTable *t, gint spacing, HTMLUndoDirection dir)
+table_set_spacing (HTMLEngine *e, HTMLTable *t, gint spacing, gboolean relative, HTMLUndoDirection dir)
 {
 	HTMLTableSetAttrUndo *undo;
+	gint new_spacing;
+
+	if (!t || !HTML_IS_TABLE (t))
+		return;
+
+	if (relative)
+		new_spacing = t->spacing + spacing;
+	else
+		new_spacing = spacing;
+	if (new_spacing < 0)
+		new_spacing = 0;
+	if (new_spacing == t->spacing)
+		return;
 
 	undo = attr_undo_new (HTML_TABLE_SPACING);
 	undo->attr.spacing = t->spacing;
 	html_undo_add_action (e->undo,
 			      html_undo_action_new ("Set table spacing", table_set_spacing_undo_action,
 						    HTML_UNDO_DATA (undo), html_cursor_get_position (e->cursor)), dir);
-	t->spacing = spacing;
+	t->spacing = new_spacing;
 	html_object_change_set (HTML_OBJECT (t), HTML_CHANGE_ALL_CALC);
 	html_engine_schedule_update (e);
 }
 
 void
-html_engine_table_set_spacing (HTMLEngine *e, HTMLTable *t, gint spacing)
+html_engine_table_set_spacing (HTMLEngine *e, HTMLTable *t, gint spacing, gboolean relative)
 {
-	table_set_spacing (e, t, spacing, HTML_UNDO_UNDO);
+	table_set_spacing (e, t, spacing, relative, HTML_UNDO_UNDO);
 }
 
 /*
@@ -813,21 +827,34 @@ html_engine_table_set_spacing (HTMLEngine *e, HTMLTable *t, gint spacing)
  *
  */
 
-static void table_set_padding (HTMLEngine *e, HTMLTable *t, gint padding, HTMLUndoDirection dir);
+static void table_set_padding (HTMLEngine *e, HTMLTable *t, gint padding, gboolean relative, HTMLUndoDirection dir);
 
 static void
 table_set_padding_undo_action (HTMLEngine *e, HTMLUndoData *undo_data, HTMLUndoDirection dir)
 {
 	HTMLTableSetAttrUndo *data = (HTMLTableSetAttrUndo *) undo_data;
 
-	table_set_padding (e, html_engine_get_table (e), data->attr.padding, html_undo_direction_reverse (dir));
+	table_set_padding (e, html_engine_get_table (e), data->attr.padding, FALSE, html_undo_direction_reverse (dir));
 }
 
 static void
-table_set_padding (HTMLEngine *e, HTMLTable *t, gint padding, HTMLUndoDirection dir)
+table_set_padding (HTMLEngine *e, HTMLTable *t, gint padding, gboolean relative, HTMLUndoDirection dir)
 {
 	HTMLTableSetAttrUndo *undo;
 	gint r, c;
+	gint new_padding;
+
+	if (!t || !HTML_IS_TABLE (t))
+		return;
+
+	if (relative)
+		new_padding = t->padding + padding;
+	else
+		new_padding = padding;
+	if (new_padding < 0)
+		new_padding = 0;
+	if (new_padding == t->padding)
+		return;
 
 	undo = attr_undo_new (HTML_TABLE_PADDING);
 	undo->attr.padding = t->padding;
@@ -835,11 +862,11 @@ table_set_padding (HTMLEngine *e, HTMLTable *t, gint padding, HTMLUndoDirection
 			      html_undo_action_new ("Set table padding", table_set_padding_undo_action,
 						    HTML_UNDO_DATA (undo), html_cursor_get_position (e->cursor)), dir);
 
-	t->padding = padding;
+	t->padding = new_padding;
 	for (r = 0; r < t->totalRows; r ++)
 		for (c = 0; c < t->totalCols; c ++)
 			if (t->cells [r][c]->col == c && t->cells [r][c]->row == r) {
-				HTML_CLUEV (t->cells [r][c])->padding = padding;
+				HTML_CLUEV (t->cells [r][c])->padding = new_padding;
 				HTML_OBJECT (t->cells [r][c])->change |= HTML_CHANGE_ALL_CALC;
 			}
 	html_object_change_set (HTML_OBJECT (t), HTML_CHANGE_ALL_CALC);
@@ -847,9 +874,9 @@ table_set_padding (HTMLEngine *e, HTMLTable *t, gint padding, HTMLUndoDirection
 }
 
 void
-html_engine_table_set_padding (HTMLEngine *e, HTMLTable *t, gint padding)
+html_engine_table_set_padding (HTMLEngine *e, HTMLTable *t, gint padding, gboolean relative)
 {
-	table_set_padding (e, t, padding, HTML_UNDO_UNDO);
+	table_set_padding (e, t, padding, relative, HTML_UNDO_UNDO);
 }
 
 /*
@@ -965,3 +992,149 @@ html_engine_table_set_width (HTMLEngine *e, HTMLTable *t, gint width, gboolean p
 {
 	table_set_width (e, t, width, percent, HTML_UNDO_UNDO);
 }
+
+gboolean
+html_engine_table_goto_0_0 (HTMLEngine *e)
+{
+	HTMLTableCell *cell;
+
+	cell = html_engine_get_table_cell (e);
+	while (cell && (cell->row != 0 || cell->col != 0)) {
+		html_engine_prev_cell (e);
+		cell = html_engine_get_table_cell (e);
+	}
+
+	return cell != NULL;
+}
+
+gboolean
+html_engine_table_goto_col (HTMLEngine *e, gint col)
+{
+	HTMLTableCell *cell;
+
+	if (html_engine_table_goto_0_0 (e)) {
+		cell = html_engine_get_table_cell (e);
+		while (cell && cell->col != col) {
+			html_engine_next_cell (e, FALSE);
+			cell = html_engine_get_table_cell (e);
+		}
+
+		return cell != NULL;
+	}
+
+	return FALSE;
+}
+
+gboolean
+html_engine_table_goto_row (HTMLEngine *e, gint row)
+{
+	HTMLTableCell *cell;
+
+	if (html_engine_table_goto_0_0 (e)) {
+		cell = html_engine_get_table_cell (e);
+		while (cell && cell->row != row) {
+			html_engine_next_cell (e, FALSE);
+			cell = html_engine_get_table_cell (e);
+		}
+
+		return cell != NULL;
+	}
+
+	return FALSE;
+}
+
+
+gboolean
+html_engine_table_goto_pos (HTMLEngine *e, gint row, gint col)
+{
+	HTMLTableCell *cell;
+
+	if (html_engine_table_goto_0_0 (e)) {
+		cell = html_engine_get_table_cell (e);
+		while (cell && cell->row != row && cell->col != col) {
+			html_engine_next_cell (e, FALSE);
+			cell = html_engine_get_table_cell (e);
+		}
+
+		return cell != NULL;
+	}
+
+	return FALSE;
+}
+
+/*
+ * set number of columns in current table
+ */
+
+void
+html_engine_table_set_cols (HTMLEngine *e, gint cols)
+{
+	HTMLTable *table = html_engine_get_table (e);
+
+	if (!table)
+		return;
+
+	if (table->totalCols == cols)
+		return;
+
+	if (table->totalCols < cols) {
+		html_engine_table_goto_col (e, table->totalCols - 1);
+		while (table->totalCols < cols)
+			html_engine_insert_table_column (e, TRUE);
+	} else {
+		html_engine_table_goto_col (e, table->totalCols - 1);
+		while (table->totalCols > cols)
+			html_engine_delete_table_column (e);
+	}
+
+	/*
+	  FIXME: jump to some well defined position (like the same position as before
+	  or at beginning of 1st new column or to last position in remaining cells
+	*/
+}
+
+/*
+ * set number of rows in current table
+ */
+
+void
+html_engine_table_set_rows (HTMLEngine *e, gint rows)
+{
+	HTMLTable *table = html_engine_get_table (e);
+
+	if (!table)
+		return;
+
+	if (table->totalRows == rows)
+		return;
+
+	if (table->totalRows < rows) {
+		html_engine_table_goto_row (e, table->totalRows - 1);
+		while (table->totalRows < rows)
+			html_engine_insert_table_row (e, TRUE);
+	} else {
+		html_engine_table_goto_row (e, table->totalRows - 1);
+		while (table->totalRows > rows)
+			html_engine_delete_table_row (e);
+	}
+
+	/*
+	  FIXME: like set_cols
+	*/
+}
+
+void
+html_engine_delete_table (HTMLEngine *e)
+{
+	HTMLTable *table;
+
+	table = html_engine_get_table (e);
+
+	if (!table)
+		return;
+	while (e->cursor->object != HTML_OBJECT (table) || e->cursor->offset)
+		html_cursor_backward (e->cursor, e);
+	html_engine_set_mark (e);
+	html_cursor_end_of_line (e->cursor, e);
+	html_engine_delete (e);
+}
