@@ -31,6 +31,7 @@
 
 #include "htmltypes.h"
 #include "htmlenums.h"
+#include "htmlcursor.h"
 
 
 #define HTML_TYPE_ENGINE                 (html_engine_get_type ())
@@ -245,6 +246,11 @@ struct _HTMLEngine {
 
 	GSList *cursor_position_stack;
 	gboolean selection_mode;
+	gint block_selection;
+
+	HTMLCursorRectangle cursor_cell;
+	HTMLCursorRectangle cursor_table;
+	HTMLCursorRectangle cursor_image;
 };
 
 /* must be forward referenced *sigh* */
@@ -297,7 +303,7 @@ gint  html_engine_calc_min_width       (HTMLEngine *e);
 void  html_engine_calc_size            (HTMLEngine *p);
 gint  html_engine_get_doc_height       (HTMLEngine *p);
 gint  html_engine_get_doc_width        (HTMLEngine *e);
-guint html_engine_get_max_width        (HTMLEngine *e);
+gint  html_engine_get_max_width        (HTMLEngine *e);
 void  html_engine_draw                 (HTMLEngine *e,
 					gint        x,
 					gint        y,
