@@ -1,6 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
    Copyright (C) 2000 Helix Code, Inc.
+   Copyright (C) 2001 Ximian, Inc.
 
    The Gnome Library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License as
@@ -17,7 +18,7 @@
    write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
 
-   Author: Radek Doulik <rodo@helixcode.com>
+   Author: Radek Doulik <rodo@ximian.com>
 
 */
 
@@ -34,7 +35,9 @@ typedef enum {
 	HTML_CHANGE_NONE = 0,
 	HTML_CHANGE_MIN_WIDTH = 1 << 0,
 	HTML_CHANGE_PREF_WIDTH = 1 << 1,
-	HTML_CHANGE_ALL = ((HTML_CHANGE_PREF_WIDTH << 1) - 1)
+	HTML_CHANGE_WORD_WIDTH = 1 << 2,
+	HTML_CHANGE_ALL_CALC = ((HTML_CHANGE_PREF_WIDTH << 1) - 1),
+	HTML_CHANGE_ALL = ((HTML_CHANGE_WORD_WIDTH << 1) - 1)
 } HTMLChangeFlags;
 
 typedef enum {
@@ -55,10 +58,7 @@ typedef enum {
 	HTML_CLUEFLOW_STYLE_H6,
 	HTML_CLUEFLOW_STYLE_ADDRESS,
 	HTML_CLUEFLOW_STYLE_PRE,
-	HTML_CLUEFLOW_STYLE_ITEMDOTTED,
-	HTML_CLUEFLOW_STYLE_ITEMROMAN,
-	HTML_CLUEFLOW_STYLE_ITEMDIGIT,
-	HTML_CLUEFLOW_STYLE_NOWRAP,
+	HTML_CLUEFLOW_STYLE_LIST_ITEM,
 	HTML_CLUEFLOW_NUMSTYLES
 } HTMLClueFlowStyle;
 
@@ -91,7 +91,8 @@ typedef enum {
 	HTML_ENGINE_SET_CLUEFLOW_STYLE = 1 << 0,
 	HTML_ENGINE_SET_CLUEFLOW_ALIGNMENT = 1 << 1,
 	HTML_ENGINE_SET_CLUEFLOW_INDENTATION = 1 << 2,
-	HTML_ENGINE_SET_CLUEFLOW_INDENTATION_DELTA = 1 << 3
+	HTML_ENGINE_SET_CLUEFLOW_INDENTATION_DELTA = 1 << 3,
+	HTML_ENGINE_SET_CLUEFLOW_INDENTATION_ALL = 5
 } HTMLEngineSetClueFlowStyleMask;
 
 typedef enum {
@@ -112,18 +113,13 @@ typedef enum {
 	HTML_HALIGN_NONE
 } HTMLHAlignType;
 
-typedef enum {
-	HTML_LIST_NUM_TYPE_NUMERIC,
-	HTML_LIST_NUM_TYPE_LOWALPHA,
-	HTML_LIST_NUM_TYPE_UPALPHA,
-	HTML_LIST_NUM_TYPE_LOWROMAN,
-	HTML_LIST_NUM_TYPE_UPROMAN
-} HTMLListNumType;
-
 typedef enum {
 	HTML_LIST_TYPE_UNORDERED,
-	HTML_LIST_TYPE_UNORDEREDPLAIN,
-	HTML_LIST_TYPE_ORDERED,
+	HTML_LIST_TYPE_ORDERED_ARABIC,
+	HTML_LIST_TYPE_ORDERED_LOWER_ALPHA,
+	HTML_LIST_TYPE_ORDERED_UPPER_ALPHA,
+	HTML_LIST_TYPE_ORDERED_LOWER_ROMAN,
+	HTML_LIST_TYPE_ORDERED_UPPER_ROMAN,
 	HTML_LIST_TYPE_MENU,
 	HTML_LIST_TYPE_DIR
 } HTMLListType;
@@ -171,6 +167,7 @@ typedef enum {
 	HTML_TYPE_IMAGE,
 	HTML_TYPE_IMAGEINPUT,
 	HTML_TYPE_LINKTEXT,
+	HTML_TYPE_MAP,
 	HTML_TYPE_OBJECT,
 	HTML_TYPE_RADIO,
 	HTML_TYPE_RULE,
@@ -183,12 +180,15 @@ typedef enum {
 	HTML_TYPE_TEXTSLAVE,
 	HTML_TYPE_VSPACE,
 	HTML_TYPE_IFRAME,
+	HTML_TYPE_FRAME,
+	HTML_TYPE_FRAMESET,
 	HTML_NUM_TYPES
 } HTMLType;
 
 typedef enum {
-	HTML_UNDO_UNDO,
-	HTML_UNDO_REDO
+	HTML_UNDO_UNDO = 0,
+	HTML_UNDO_REDO = 1,
+	HTML_UNDO_END  = 2
 } HTMLUndoDirection;
 
 typedef enum {
@@ -205,7 +205,7 @@ typedef enum {
 
 typedef enum {
 	HTML_VALIGN_TOP,
-	HTML_VALIGN_CENTER,
+	HTML_VALIGN_MIDDLE,
 	HTML_VALIGN_BOTTOM,
 	HTML_VALIGN_NONE
 } HTMLVAlignType;
