@@ -27,6 +27,10 @@
 #include <gdk-pixbuf/gdk-pixbuf-loader.h>
 #include "htmlobject.h"
 
+#define HTML_IMAGE_FACTORY(x) ((HTMLImageFactory *)(x))
+#define HTML_IMAGE_POINTER(x) ((HTMLImagePointer *)(x))
+#define HTML_IS_IMAGE(x) (HTML_CHECK_TYPE ((x), HTML_TYPE_IMAGE))
+
 struct _HTMLImagePointer {
 	gint refcount;
 	gchar *url;
@@ -35,6 +39,8 @@ struct _HTMLImagePointer {
 	GdkPixbufAnimation *animation;
 	GSList *interests; /* A list of HTMLImage's, or a NULL pointer for the background pixmap */
 	HTMLImageFactory *factory;
+	gint stall;
+	guint stall_timeout;
 };
 
 struct _HTMLImageAnimation {
@@ -76,8 +82,9 @@ struct _HTMLImage {
 
 	gint16 specified_width;
 	gint16 specified_height;
-	gboolean percent_width;
-	gboolean percent_height;
+	gboolean percent_width  : 1;
+	gboolean percent_height : 1;
+	gboolean ismap : 1;
 
 	gint8 hspace;
 	gint8 vspace;
@@ -86,7 +93,9 @@ struct _HTMLImage {
 
 	gchar *url;
 	gchar *target;
-	gchar *alt;	
+	gchar *alt;
+	gchar *usemap;
+	gchar *final_url;	
 };
 
 struct _HTMLImageClass {
@@ -141,6 +150,9 @@ void        html_image_set_border         (HTMLImage        *image,
 					   gint              border);
 void        html_image_set_alt            (HTMLImage        *image,
 					   gchar            *alt);
+void        html_image_set_map            (HTMLImage        *image,
+					   gchar            *mapuri,
+					   gboolean         ismap);
 gchar      *html_image_resolve_image_url  (GtkHTML          *html,
 					   gchar            *image_url);
 
@@ -157,4 +169,6 @@ HTMLImagePointer *html_image_factory_register    (HTMLImageFactory *factory,
 void              html_image_factory_unregister  (HTMLImageFactory *factory,
 						  HTMLImagePointer *pointer,
 						  HTMLImage        *i);
+void              html_image_factory_move_images (HTMLImageFactory *dst,
+						  HTMLImageFactory *src);
 #endif /* _HTMLIMAGE_H_ */
