@@ -38,7 +38,9 @@ html_undo_action_new (const gchar *description, HTMLUndoFunc function, HTMLUndoD
 	action->function    = function;
 	action->data        = data;
 	action->position    = position;
-
+#ifdef UNDO_DEBUG
+	action->is_level    = FALSE;
+#endif
 	return action;
 }
 
@@ -47,7 +49,8 @@ html_undo_action_destroy (HTMLUndoAction *action)
 {
 	g_return_if_fail (action != NULL);
 
-	html_undo_data_unref (action->data);
+	if (action->data)
+		html_undo_data_unref (action->data);
 	g_free (action->description);
 	g_free (action);
 }
